package com.ruoyi.project.training.bccnew.service.impl;

import java.util.List;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.ruoyi.project.training.bccnew.mapper.TTsFlplanTmplContentMapper;
import com.ruoyi.project.training.bccnew.domain.TTsFlplanTmplContent;
import com.ruoyi.project.training.bccnew.service.ITTsFlplanTmplContentService;

/**
 * 分离培训模版内容Service业务层处理
 *
 * @author ssy
 * @date 2024-07-19
 */
@Service
public class TTsFlplanTmplContentServiceImpl implements ITTsFlplanTmplContentService
{
    @Autowired
    private TTsFlplanTmplContentMapper tTsFlplanTmplContentMapper;

    /**
     * 查询分离培训模版内容
     *
     * @param id 分离培训模版内容ID
     * @return 分离培训模版内容
     */
    @Override
    public TTsFlplanTmplContent selectTTsFlplanTmplContentById(Long id)
    {
        return tTsFlplanTmplContentMapper.selectTTsFlplanTmplContentById(id);
    }

    /**
     * 查询分离培训模版内容列表
     *
     * @param tTsFlplanTmplContent 分离培训模版内容
     * @return 分离培训模版内容
     */
    @Override
    public List<TTsFlplanTmplContent> selectTTsFlplanTmplContentList(TTsFlplanTmplContent tTsFlplanTmplContent)
    {
        return tTsFlplanTmplContentMapper.selectTTsFlplanTmplContentList(tTsFlplanTmplContent);
    }

    /**
     * 新增分离培训模版内容
     *
     * @param tTsFlplanTmplContent 分离培训模版内容
     * @return 结果
     */
    @Override
    public int insertTTsFlplanTmplContent(TTsFlplanTmplContent tTsFlplanTmplContent)
    {
        return tTsFlplanTmplContentMapper.insertTTsFlplanTmplContent(tTsFlplanTmplContent);
    }

    /**
     * 修改分离培训模版内容
     *
     * @param tTsFlplanTmplContent 分离培训模版内容
     * @return 结果
     */
    @Override
    public int updateTTsFlplanTmplContent(TTsFlplanTmplContent tTsFlplanTmplContent)
    {
        return tTsFlplanTmplContentMapper.updateTTsFlplanTmplContent(tTsFlplanTmplContent);
    }

    /**
     * 批量删除分离培训模版内容
     *
     * @param ids 需要删除的分离培训模版内容ID
     * @return 结果
     */
    @Override
    public int deleteTTsFlplanTmplContentByIds(Long[] ids)
    {
        return tTsFlplanTmplContentMapper.deleteTTsFlplanTmplContentByIds(ids);
    }

    /**
     * 删除分离培训模版内容信息
     *
     * @param id 分离培训模版内容ID
     * @return 结果
     */
    @Override
    public int deleteTTsFlplanTmplContentById(Long id)
    {
        return tTsFlplanTmplContentMapper.deleteTTsFlplanTmplContentById(id);
    }
}
