package com.ruoyi.project.training.bccnew.controller;

import java.util.List;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.ruoyi.framework.aspectj.lang.annotation.Log;
import com.ruoyi.framework.aspectj.lang.enums.BusinessType;
import com.ruoyi.project.training.bccnew.domain.TTsFlplanTmplContent;
import com.ruoyi.project.training.bccnew.service.ITTsFlplanTmplContentService;
import com.ruoyi.framework.web.controller.BaseController;
import com.ruoyi.framework.web.domain.AjaxResult;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.framework.web.page.TableDataInfo;

/**
 * 分离培训模版内容Controller
 *
 * @author ssy
 * @date 2024-07-19
 */
@RestController
@RequestMapping("/bccnew/flTmplContent")
public class TTsFlplanTmplContentController extends BaseController
{
    @Autowired
    private ITTsFlplanTmplContentService tTsFlplanTmplContentService;

    /**
     * 查询分离培训模版内容列表
     */
    //@PreAuthorize("@ss.hasPermi('bccnew:flTmplContent:list')")
    @GetMapping("/list")
    public TableDataInfo list(TTsFlplanTmplContent tTsFlplanTmplContent)
    {
        startPage();
        List<TTsFlplanTmplContent> list = tTsFlplanTmplContentService.selectTTsFlplanTmplContentList(tTsFlplanTmplContent);
        return getDataTable(list);
    }

    /**
     * 导出分离培训模版内容列表
     */
    //@PreAuthorize("@ss.hasPermi('bccnew:flTmplContent:export')")
    @Log(title = "分离培训模版内容", businessType = BusinessType.EXPORT)
    @GetMapping("/export")
    public AjaxResult export(TTsFlplanTmplContent tTsFlplanTmplContent)
    {
        List<TTsFlplanTmplContent> list = tTsFlplanTmplContentService.selectTTsFlplanTmplContentList(tTsFlplanTmplContent);
        ExcelUtil<TTsFlplanTmplContent> util = new ExcelUtil<TTsFlplanTmplContent>(TTsFlplanTmplContent.class);
        return util.exportExcel(list, "flTmplContent");
    }

    /**
     * 获取分离培训模版内容详细信息
     */
    //@PreAuthorize("@ss.hasPermi('bccnew:flTmplContent:query')")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id)
    {
        return AjaxResult.success(tTsFlplanTmplContentService.selectTTsFlplanTmplContentById(id));
    }

    /**
     * 新增分离培训模版内容
     */
    //@PreAuthorize("@ss.hasPermi('bccnew:flTmplContent:add')")
    @Log(title = "分离培训模版内容", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody TTsFlplanTmplContent tTsFlplanTmplContent)
    {
        return toAjax(tTsFlplanTmplContentService.insertTTsFlplanTmplContent(tTsFlplanTmplContent));
    }

    /**
     * 修改分离培训模版内容
     */
    //@PreAuthorize("@ss.hasPermi('bccnew:flTmplContent:edit')")
    @Log(title = "分离培训模版内容", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody TTsFlplanTmplContent tTsFlplanTmplContent)
    {
        return toAjax(tTsFlplanTmplContentService.updateTTsFlplanTmplContent(tTsFlplanTmplContent));
    }

    /**
     * 删除分离培训模版内容
     */
    //@PreAuthorize("@ss.hasPermi('bccnew:flTmplContent:remove')")
    @Log(title = "分离培训模版内容", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids)
    {
        return toAjax(tTsFlplanTmplContentService.deleteTTsFlplanTmplContentByIds(ids));
    }
}
